==> ssp-center-api-0.0.17-lqs16-20170616.024328-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotBackendService.java <==
/**
 * Project Name:media-api<br>
 * File Name:RemoteSlotService.java<br>
 * Package Name:cn.com.duiba.tuia.media.api.remoteservice<br>
 * Date:2016年9月30日下午4:21:08<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.tuia.ssp.center.api.dto.IdAndNameDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqSlotList;
import java.util.List;

import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName: RemoteSlotService <br/>
 * Function: 广告位. <br/>
 * date: 2016年9月30日 下午4:21:08 <br/>
 *
 * @author leiliang
 * @version
 * @since JDK 1.6
 */
public interface RemoteSlotBackendService {

    /**
     * 查询广告位详情.
     *
     * @param slotId 广告位id
     * @return 广告位详情
     */
    DubboResult<RspSlotBackendDetailDto> getDetail(Long slotId);

    /**
     * 查询广告位对应的SDK信息
     * @param slotId
     * @return
     */
    DubboResult<List <SdkInfoDto>> getSdkInfo(Long slotId);

    /**
     * 查询广告位集合.
     *
     * @param slotIds the slot ids
     * @return the detail
     */
    DubboResult<List<SlotDto>> getListDetail(List<Long> slotIds);

    /**
     * 分页查询广告位数据.
     *
     * @param req the req
     * @return the slots by page
     */
    DubboResult<PageResultDto<RspAdsenseSlotListDto>> getSlotsByPage(ReqGetSlotsByPageDto req);

    /**
     * 批量更新广告位审核状态.
     *
     * @param slotIds 广告位ID列表
     * @param status 审核操作(0:待审核，1:审核拒绝， 2：审核通过)
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> batchUpdateCheckStatus(List<Long> slotIds, Integer status);

    /**
     * 更新广告位.
     *
     * @param param the param
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> update(ReqUpdateSlotStrategy param);

    /**
     * 查看广告选择类型参数
     * 
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<SlotTypeParamDto>> selectSlotTypeParam();

    /**
     * 修改广告部分属性
     * 
     * @param slotDto
     * @return boolean
     */
    DubboResult<Boolean> updateSlot(SlotDto slotDto);

    /**
     * 通过广告位名称查询广告id集合
     * 
     * @param slotName
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<Long>> getSlotIdsByName(String slotName);

    /**
     * 获取缓存中的所有的广告id和名称
     * 
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> getAllSlotIdAndNameCache();

    /**
     * 删除缓存中的所有的广告id和名称
     * 
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> delAllSlotIdAndNameCache();

    /**
     * getSlotById:(通过广告位Id查询广告位详情). <br/>
     *
     * @param slotId
     * @return
     * @since JDK 1.6
     */
    DubboResult<SlotDto> getSlotById(Long slotId);

    /**
     * getSlotByIdCache:(通过广告位ID查询缓存中的广告位对象信息). <br/>
     *
     * @param slotId
     * @return
     * @since JDK 1.6
     */
    DubboResult<SlotCacheDto> getSlotByIdCache(Long slotId);

    /**
     * selectSlotByAppId:(根据appId获取app下所有广告位信息). <br/>
     *
     * @author ZFZ
     * @param appId
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<SlotDto>> selectSlotByAppId(Long appId);

    /**
     * selectSlotConfigListByAppId:(根据appId获取app下所有广告位配置信息). <br/>
     *
     * @author ZFZ
     * @param appId
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<SlotConfigDto>> selectSlotConfigListByAppId(Long appId);

    /**
     * updateSlotConfig:(更新广告位配置信息). <br/>
     *
     * @author ZFZ
     * @param dto
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> updateSlotConfig(SlotConfigDto dto);

    /**
     *  从长期配置表同步
     * @return
     */
    DubboResult<Boolean> scheduleUpdateSlotConfig();

    DubboResult<Integer> insert(SlotDto record);

    DubboResult<List<SlotDto>> selectListByPage(ReqSlotList reqSlotList);

    DubboResult<Integer> updateDelStatus(Long slotId, Long mediaId);

    DubboResult<Integer> selectAmountByPage(ReqSlotList reqSlotList);

    DubboResult<List<IdAndNameDto>> selectIdsByMediaId4data(Long mediaId);

    DubboResult<List<SlotDto>> selectListByPage4data(ReqSlotList param);
}

==> ssp-center-api-0.1.9-lqs3-20170725.061632-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotBackendService.java <==
/**
 * Project Name:media-api<br>
 * File Name:RemoteSlotService.java<br>
 * Package Name:cn.com.duiba.tuia.media.api.remoteservice<br>
 * Date:2016年9月30日下午4:21:08<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.tuia.ssp.center.api.dto.IdAndNameDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqSlotList;
import java.util.List;

import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName: RemoteSlotService <br/>
 * Function: 广告位. <br/>
 * date: 2016年9月30日 下午4:21:08 <br/>
 *
 * @author leiliang
 * @version
 * @since JDK 1.6
 */
public interface RemoteSlotBackendService {

    /**
     * 查询广告位详情.
     *
     * @param slotId 广告位id
     * @return 广告位详情
     */
    DubboResult<RspSlotBackendDetailDto> getDetail(Long slotId);

    /**
     * 查询广告位对应的SDK信息
     * @param slotId
     * @return
     */
    DubboResult<List <SdkInfoDto>> getSdkInfo(Long slotId);

    /**
     * 查询广告位集合.
     *
     * @param slotIds the slot ids
     * @return the detail
     */
    DubboResult<List<SlotDto>> getListDetail(List<Long> slotIds);

    /**
     * 分页查询广告位数据.
     *
     * @param req the req
     * @return the slots by page
     */
    DubboResult<PageResultDto<RspAdsenseSlotListDto>> getSlotsByPage(ReqGetSlotsByPageDto req);

    /**
     * 批量更新广告位审核状态.
     *
     * @param slotIds 广告位ID列表
     * @param status 审核操作(0:待审核，1:审核拒绝， 2：审核通过)
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> batchUpdateCheckStatus(List<Long> slotIds, Integer status);

    /**
     * 更新广告位.
     *
     * @param param the param
     * @return the dubbo result< boolean>
     */
    DubboResult<Boolean> update(ReqUpdateSlotStrategy param);

    /**
     * 查看广告选择类型参数
     * 
     * @author guyan
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<SlotTypeParamDto>> selectSlotTypeParam();

    /**
     * 修改广告部分属性
     * 
     * @param slotDto
     * @return boolean
     */
    DubboResult<Boolean> updateSlot(SlotDto slotDto);

    /**
     * 通过广告位名称查询广告id集合
     * 
     * @param slotName
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<Long>> getSlotIdsByName(String slotName);

    /**
     * 获取缓存中的所有的广告id和名称
     * 
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> getAllSlotIdAndNameCache();

    /**
     * 删除缓存中的所有的广告id和名称
     * 
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> delAllSlotIdAndNameCache();

    /**
     * getSlotById:(通过广告位Id查询广告位详情). <br/>
     *
     * @param slotId
     * @return
     * @since JDK 1.6
     */
    DubboResult<SlotDto> getSlotById(Long slotId);

    /**
     * getSlotByIdCache:(通过广告位ID查询缓存中的广告位对象信息). <br/>
     *
     * @param slotId
     * @return
     * @since JDK 1.6
     */
    DubboResult<SlotCacheDto> getSlotByIdCache(Long slotId);

    /**
     * selectSlotByAppId:(根据appId获取app下所有广告位信息). <br/>
     *
     * @author ZFZ
     * @param appId
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<SlotDto>> selectSlotByAppId(Long appId);

    /**
     * selectSlotConfigListByAppId:(根据appId获取app下所有广告位配置信息). <br/>
     *
     * @author ZFZ
     * @param appId
     * @return
     * @since JDK 1.6
     */
    DubboResult<List<SlotConfigDto>> selectSlotConfigListByAppId(Long appId);

    /**
     * updateSlotConfig:(更新广告位配置信息). <br/>
     *
     * @author ZFZ
     * @param dto
     * @return
     * @since JDK 1.6
     */
    DubboResult<Boolean> updateSlotConfig(SlotConfigDto dto);

    /**
     *  从长期配置表同步
     * @return
     */
    DubboResult<Boolean> scheduleUpdateSlotConfig();

    DubboResult<SlotDto> insert(SlotDto record);

    DubboResult<List<SlotDto>> selectListByPage(ReqSlotList reqSlotList);

    DubboResult<Integer> updateDelStatus(Long slotId, Long mediaId);

    DubboResult<Integer> selectAmountByPage(ReqSlotList reqSlotList);

    DubboResult<List<IdAndNameDto>> selectIdsByMediaId4data(Long mediaId);

    DubboResult<List<SlotDto>> selectListByPage4data(ReqSlotList param);
    
    /**
     * 根据appId列表批量查询广告位信息
     * @param appIds
     * @return
     */
    DubboResult<List<SlotDto>> selectListByAppIds(List<Long> appIds);
}
